.. _transports_module:

:mod:`socketio.transports`
==========================

This is largely an internal module, responsible for translating the
different fallback mechanisms to one abstracted Socket, dealing with
payload encoding, multi-message multiplexing and their reverse operation.

.. automodule:: socketio.transports
    :members:
    :undoc-members:
    :show-inheritance:
